# Generated by roxygen2: do not edit by hand

export(OpenRange_api_load_species)
export(OpenRange_api_species)
export(OpenRange_get_license)
export(OpenRange_get_stats)
export(OpenRange_list_scenarios)
export(OpenRange_load_species)
export(OpenRange_sf)
export(OpenRange_species)
import(RPostgreSQL)
import(sf)
importFrom(httr,GET)
importFrom(jsonlite,fromJSON)
importFrom(sf,st_as_sf)
importFrom(sf,st_write)
