# Open Range

The goal of this repository is to provide access to a proof-of-concept Open Range database. The intent behind this Open Range database is to provide Open Access species range maps, along with associated metadata needed to judge map quality and suitability for different purposes. The maps within the database are licensed under a <a href="https://creativecommons.org/licenses/by/4.0/">CC-BY 4.0</a> license. The current database is focused on plants, primarily from the Americas, but we intend on expanding the scope in the future.

## Disclaimer

These maps are a <b>pre-alpha</b> version intended primarily as a <b>proof-of-concept</b> and have not been fully assessed or undergone a thorough QA/QC. While the associated metadata can be used to judge performance, these maps <b> should not be used</b> without critical evaluation by the user.

## Installation
This package can be installed using the `install_github` function in the `devtools` R package.

```
library(devtools)
install_github(repo = "MaitnerLab/OpenRange")


```
