% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/internals.R
\name{.is_char}
\alias{.is_char}
\title{Check that value is character}
\usage{
.is_char(x)
}
\description{
Helper function to check data format.
}
\keyword{internal}
